pub struct Song {
pub title: String,
pub composer: String,
pub style: String,
pub key_signature: String,
pub progression: Progression,
}Expand description
Represents a song with an iReal Pro progression.
Includes information such as the title, composer, style, key signature, and chord progression.
Fields
title: StringSong Title (If starting with ‘The’ change the title to ‘Song Title, The’ for sorting purposes)
composer: StringComposer’s LastName FirstName (we put the last name first for sorting purposes within the app)
style: StringStyle (A short text description of the style used for sorting in the app. Medium Swing, Ballad, Pop, Rock…)
key_signature: StringKey Signature (C, Db, D, Eb, E, F, Gb, G, Ab, A, Bb, B, A-, Bb-, B-, C-, C#-, D-, Eb-, E-, F-, F#-, G-, G#-)
progression: ProgressionChord Progression (This is the main part)